==> superlinked-2.36.0.tar.gz: superlinked-2.36.0/superlinked/framework/dsl/index/effect.py <==
# Copyright 2024 Superlinked, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass

from superlinked.framework.common.exception import InitializationException
from superlinked.framework.common.interface.comparison_operand import (
    ComparisonOperation,
)
from superlinked.framework.common.schema.schema_object import SchemaField
from superlinked.framework.common.schema.schema_reference import (
    MultipliedSchemaReference,
    SchemaReference,
)
from superlinked.framework.dsl.space.space import Space


@dataclass
class Effect:
    """
    An effect represents a conditional interaction within a `Space` where the
    `affecting_schema_reference` interacted with the `affected_schema_reference`.

    It allows you to real-time adjust embeddings based on interaction.
    e.g.: A `User` schema interacts with a `Post` schema, if `event.type == 'like'.
    """

    space: Space
    affected_schema_reference: SchemaReference
    affecting_schema_reference: SchemaReference | MultipliedSchemaReference
    filter_: ComparisonOperation[SchemaField]

    def __post_init__(self) -> None:
        if not isinstance(self.affected_schema_reference, SchemaReference):
            raise InitializationException(
                f"{self.__class__.__name__} must have an affected_schema_reference"
                + f" of the type {SchemaReference.__name__}"
            )

    def __str__(self) -> str:
        result = f"{self.space}:{self.affected_schema_reference}:{self.affecting_schema_reference}:{self.filter_}"
        return result

==> superlinked-3.33.0.tar.gz: superlinked-3.33.0/superlinked/framework/dsl/index/effect.py <==
# Copyright 2024 Superlinked, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass

from superlinked.framework.common.interface.comparison_operand import (
    ComparisonOperation,
)
from superlinked.framework.common.schema.schema_object import SchemaField
from superlinked.framework.common.schema.schema_reference import (
    MultipliedSchemaReference,
    SchemaReference,
)
from superlinked.framework.common.util.type_validator import TypeValidator
from superlinked.framework.dsl.space.space import Space


@TypeValidator.wrap
@dataclass
class Effect:
    """
    An effect represents a conditional interaction within a `Space` where the
    `affecting_schema_reference` interacted with the `affected_schema_reference`.

    It allows you to real-time adjust embeddings based on interaction.
    e.g.: A `User` schema interacts with a `Post` schema, if `event.type == 'like'.
    """

    space: Space
    affected_schema_reference: SchemaReference
    affecting_schema_reference: SchemaReference | MultipliedSchemaReference
    filter_: ComparisonOperation[SchemaField]

    def __str__(self) -> str:
        return (
            f"{self.__class__.__name__}(space={self.space}, filter={self.filter_}, "
            f"affected_schema_reference={self.affected_schema_reference}, "
            f"affecting_schema_reference={self.affecting_schema_reference})"
        )
